==> kdebase-3.0.1.tar.bz2: kdebase-3.0.1/kicker/ui/addcontainer_mnu.cpp <==
/*****************************************************************

Copyright (c) 2001 Matthias Elter <elter@kde.org>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#include <klocale.h>
#include <kglobal.h>
#include <kdebug.h>

#include "addcontainer_mnu.h"
#include "addcontainer_mnu.moc"

#include "addapplet_mnu.h"
#include "addbutton_mnu.h"
#include "addextension_mnu.h"
#include "addspecialbutton_mnu.h"
#include "pluginmanager.h"

AddContainerMenu::AddContainerMenu( ContainerArea* containerArea, bool showExtensions,
				    QWidget *parent, const char *name)
    : QPopupMenu( parent, name )
{
    appletId = insertItem( i18n( "Applet" ),
			   new PanelAddAppletMenu( containerArea, this ) );
    buttonId = insertItem( i18n( "Button" ),
			   new PanelAddButtonMenu( containerArea, this ) );
    if ( showExtensions )
	extensionId = insertItem( i18n( "Extension" ),
				  new PanelAddExtensionMenu( this ) );
    else
	extensionId = -1;
    specialId = insertItem( i18n( "Special Button" ),
			    new PanelAddSpecialButtonMenu( containerArea, this ) );
    adjustSize();
    connect( this, SIGNAL( aboutToShow() ), SLOT( slotAboutToShow() ) );
}

AddContainerMenu::~AddContainerMenu()
{

}

void AddContainerMenu::slotAboutToShow()
{
    setItemEnabled( appletId, PluginManager::pluginManager()->applets().count() > 0 );
    setItemEnabled( extensionId, PluginManager::pluginManager()->extensions().count() > 0 );
}

==> kdebase-3.1.4.tar.bz2: kdebase-3.1.4/kicker/ui/addcontainer_mnu.cpp <==
/*****************************************************************

Copyright (c) 2001 Matthias Elter <elter@kde.org>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#include <klocale.h>
#include <kglobal.h>
#include <kdebug.h>

#include "addcontainer_mnu.h"
#include "addcontainer_mnu.moc"

#include "addapplet_mnu.h"
#include "addbutton_mnu.h"
#include "addextension_mnu.h"
#include "addspecialbutton_mnu.h"
#include "pluginmanager.h"

AddContainerMenu::AddContainerMenu( ContainerArea* containerArea, bool showExtensions,
				    QWidget *parent, const char *name)
    : QPopupMenu( parent, name )
{
    appletId = insertItem( i18n( "Applet" ),
			   new PanelAddAppletMenu( containerArea, this ) );
    buttonId = insertItem( i18n( "Application Button" ),
			   new PanelAddButtonMenu( containerArea, this ) );
    specialId = insertItem( i18n( "Special Button" ),
                            new PanelAddSpecialButtonMenu( containerArea, this ) );

    if ( showExtensions )
	extensionId = insertItem( i18n( "Extension" ),
				  new PanelAddExtensionMenu( this ) );
    else
	extensionId = -1;
    adjustSize();
    connect( this, SIGNAL( aboutToShow() ), SLOT( slotAboutToShow() ) );
}

AddContainerMenu::~AddContainerMenu()
{

}

void AddContainerMenu::slotAboutToShow()
{
    setItemEnabled( appletId, PluginManager::pluginManager()->applets().count() > 0 );
    setItemEnabled( extensionId, PluginManager::pluginManager()->extensions().count() > 0 );
}
